###################################################
### chunk number 1: aneurism load
###################################################
library(survival) 
library(intcox) 
data(AA.data)
AA.data[1:11,] 


###################################################
### chunk number 2: aneurism preparation
###################################################
AA.data$t.left<-ifelse(AA.data$z==1,0,AA.data$obs.t)
AA.data$t.right<-ifelse(AA.data$z==1,AA.data$obs.t,NA)


###################################################
### chunk number 3: aneurism fit
###################################################
AA.fit<-intcox(Surv(t.left,t.right,type="interval2")~mo+lok,data=AA.data)
summary(AA.fit)


###################################################
### chunk number 4: aneurismplot
###################################################
surv.base<-exp(-AA.fit$lambda0)
plot(AA.fit$time.point,surv.base,type="s",xlab="time [years]",ylab="Survival function",lty=1)
lines(AA.fit$time.point,surv.base^exp(AA.fit$coefficients["mo"]),type="s",lty=2)
lines(AA.fit$time.point,surv.base^exp(AA.fit$coefficients["lok"]),type="s",lty=3)
lines(AA.fit$time.point,surv.base^exp(sum(AA.fit$coefficients[c("mo","lok")])),type="s",lty=5)
leg.names<-c("mo=0, lok=0", "mo=0, lok=1","mo=1, lok=0","mo=1, lok=1")
legend(4,1,leg.names,lty=c(1,2,3,5),bty="n")


###################################################
### chunk number 5: aneurism bootstrap
###################################################
set.seed(123)
pat<-unique(AA.data$gr)
intcox.boot.AA<-function(i,form) {
   boot.sample<-sample(pat,length(pat),replace=T)
   data.ind<-unlist(lapply(boot.sample,function(x,yy) which(yy==x),yy=AA.data$gr))
   data.sample<-AA.data[data.ind,]
   boot.fit<-intcox(form,data=data.sample, no.warnings = TRUE)
   return(list(coef=coef(boot.fit),term=boot.fit$termination))
   }
n.rep<-9                                #to be set on something like 999
AA.boot<-lapply(1:n.rep,intcox.boot.AA,form=Surv(t.left,t.right,type="interval2")~mo+lok)
AA.boot<-matrix(unlist(AA.boot),byrow=T,nrow=n.rep)
colnames(AA.boot)<-c(names(coef(AA.fit)),"termination")
inf.level<-0.05 
mo.ord<-order(AA.boot[,"mo"])
lok.ord<-order(AA.boot[,"lok"])
pos.lower<-ceiling((n.rep+1)*(inf.level/2))
pos.upper<-ceiling((n.rep+1)*(1-inf.level/2))
ci.mo<-AA.boot[mo.ord,"mo"][c(pos.lower,pos.upper)]
ci.lok<-AA.boot[mo.ord,"lok"][c(pos.lower,pos.upper)] 
ci.mo 
ci.lok
summary(AA.boot[,"mo"]) 
summary(AA.boot[,"lok"])
bias.mo<-c(mean.bias=coef(AA.fit)["mo"]-mean(AA.boot[,"mo"]),median.bias=coef(AA.fit)["mo"]-median(AA.boot[,"mo"]))
bias.lok<-c(mean.bias=coef(AA.fit)["lok"]-mean(AA.boot[,"lok"]),median.bias=coef(AA.fit)["lok"]-median(AA.boot[,"lok"]))
bias.mo 
bias.lok 
table(AA.boot[,"termination"])


###################################################
### chunk number 6: aneurism interaction
###################################################
AA.int.fit<-intcox(Surv(t.left,t.right,type="interval2")~mo*lok,data=AA.data)
summary(AA.int.fit)
set.seed(234)
n.rep<-9                                #to be set on something like 999
AA.int.boot<-lapply(1:n.rep,intcox.boot.AA,form=Surv(t.left,t.right,type="interval2")~mo*lok)
AA.int.boot<-matrix(unlist(AA.int.boot),byrow=T,nrow=n.rep)
colnames(AA.int.boot)<-c(names(coef(AA.int.fit)),"termination")
inf.level<-0.05
int.ord<-order(AA.int.boot[,"mo:lok"])
pos.lower<-ceiling((n.rep+1)*(inf.level/2))
pos.upper<-ceiling((n.rep+1)*(1-inf.level/2))
ci.int<-AA.int.boot[int.ord,"mo:lok"][c(pos.lower,pos.upper)]
ci.int
summary(AA.int.boot[,"mo:lok"])
bias.int<-c(mean.bias=coef(AA.int.fit)["mo:lok"]-mean(AA.int.boot[,"mo:lok"]),median.bias=coef(AA.int.fit)["mo:lok"]-median(AA.int.boot[,"mo:lok"]))
bias.int
table(AA.int.boot[,"termination"])


###################################################
### chunk number 7: aneurism LRT
###################################################
AA.int.fit$loglik
AA.fit$loglik


###################################################
### chunk number 8: aneurism export
###################################################
getwd()
write.table(AA.data, file = "AA.csv", sep = ",", na = "." , col.names = NA)


